// CountdownDialog.cpp
// 
// Revision Log
//
// Date       Who SAR     Notes
// ========== === ======= =====================================
// 2001-08-01 mph         Initial coding by Mark Henri of
//                        MPH Software - markhenri@home.net
// 

#include "stdafx.h"

#define COUNTDOWNDIALOG_CPP
#include "CountdownDialog.h"
#include <windowsx.h>
#include <commctrl.h>

#include <process.h>
#include "resource.h"

//#include <Comcthlp.h>
#define Progress_SetRange( hwnd, nMinRange, nMaxRange ) \
   ( DWORD )SendMessage( ( hwnd ), PBM_SETRANGE, 0, MAKELPARAM( nMinRange, nMaxRange ) )
#define Progress_SetPos( hwnd, nNewPos ) \
   ( int )SendMessage( ( hwnd ), PBM_SETPOS,( WPARAM ) nNewPos, 0L )


#define USE_THREADING_MODEL 0

HINSTANCE CountdownDialogInstance = NULL;

BOOL APIENTRY DllMain( HANDLE hModule, 
                       DWORD  ul_reason_for_call, 
                       LPVOID lpReserved
					 )
{
	if ( ul_reason_for_call == DLL_PROCESS_ATTACH )
      CountdownDialogInstance = (HINSTANCE)hModule;
   
   return TRUE;
}

const char* CountdownDialogszTitle = NULL;
const char* CountdownDialogszPrompt = NULL;
long CountdownDialogSeconds = 0;
int CountdownDialogDefButton = IDOK;
BOOL CountdownDialogEndOnInactive = false;

#if USE_THREADING_MODEL
BOOL CountdownDialogProcedureActive = FALSE;

VOID CountdownDialogThread (PVOID pvoid)
{
   HWND hwnd = reinterpret_cast<HWND>( pvoid );
   HWND hProgress = GetDlgItem( hwnd, IDC_PROGRESS );
   Progress_SetRange( hProgress, 0, 100 );

   for (long n=100; n >= 0; n-- )
   {
      if ( ! CountdownDialogProcedureActive )
      {
         ExitThread(0);
         return;
      }
      Progress_SetPos( hProgress, n );
      Sleep( ( CountdownDialogSeconds*1000 ) / 100 );
   }

   if ( CountdownDialogProcedureActive )
   {
      if ( hwnd )
         SendMessage( hwnd, WM_COMMAND, CountdownDialogDefButton, 0 );
   }
   ExitThread(0);
}
#endif

BOOL CALLBACK CountdownDialogProcedure ( HWND hwnd, UINT message, UINT wParam, LPARAM lParam )
{
   #if ! USE_THREADING_MODEL
   static int timerLoopCount = 100;
   static HWND hProgress     = NULL;
   static DWORD dwStartTicks = 0;
   #endif

   switch (message)
   {
   case WM_INITDIALOG:
      {
      SetWindowText( hwnd, CountdownDialogszTitle );
      SetDlgItemText( hwnd, IDC_PROMPT, CountdownDialogszPrompt );
      
      #if USE_THREADING_MODEL
      CountdownDialogProcedureActive = TRUE;
      _beginthread( CountdownDialogThread, 0, (void*)hwnd );
      #else
      timerLoopCount = 100;
      dwStartTicks = GetTickCount();
      SetTimer( hwnd, 1, 100, NULL );
      hProgress = GetDlgItem( hwnd, IDC_PROGRESS );
      Progress_SetRange( hProgress, 0, 100 );
      #endif
      }
      return TRUE;

   case WM_ACTIVATE:
      if ( CountdownDialogEndOnInactive && 
         LOWORD(wParam) == WA_INACTIVE )
            PostMessage(hwnd, WM_COMMAND, CountdownDialogDefButton, 0);
      return FALSE;

   #if ! USE_THREADING_MODEL
   case WM_TIMER:
      {
         DWORD dwElapsed = GetTickCount() - dwStartTicks;
         DWORD dwPercent = 100 - ( ( dwElapsed * 100 ) / ( CountdownDialogSeconds * 1000 ) );

         Progress_SetPos( hProgress, dwPercent );
         if ( dwPercent < 1 || dwPercent > 100 )
         {
            KillTimer( hwnd, 1 );
            EndDialog (hwnd, CountdownDialogDefButton);
         }
      }
      return FALSE;
   #endif

   case WM_COMMAND:
      switch (LOWORD (wParam))
      {
      case IDOK:
         EndDialog (hwnd, IDOK);
         #if USE_THREADING_MODEL
         CountdownDialogProcedureActive = FALSE;
         #endif
         return TRUE;
      case IDCANCEL:
         EndDialog (hwnd, IDCANCEL);
         #if USE_THREADING_MODEL
         CountdownDialogProcedureActive = FALSE;
         #endif
         return TRUE;
      }
      break;
   }
   return FALSE;
}

CDDEXPORT int CDDCALLINGFORMAT CountdownDialog( HWND hwnd, const char* prompt, 
                               const char* title, long milliseconds,
                               int defbutton, BOOL endoninactive )
{
#ifdef _DEBUG
   //if ( MessageBox(NULL, "In CountdownDialog(...), continue...", "Status", MB_OKCANCEL | MB_ICONINFORMATION ) == IDCANCEL )
   //   return 0;
#endif
   if ( hwnd == NULL )
   {
      char achPrompt[256];
      char achCaption[256];
      LoadString( CountdownDialogInstance, IDS_CDD, achCaption, sizeof( achCaption ) );
      LoadString( CountdownDialogInstance, IDS_ERROR_NULL_PARENT_HWND, achPrompt, sizeof( achPrompt ) );
      MessageBox( NULL, achPrompt, achCaption, MB_OK );
      return 0;
   }

   CountdownDialogszTitle = title;
   CountdownDialogszPrompt = prompt;
   CountdownDialogSeconds = milliseconds;
   CountdownDialogDefButton = defbutton;
   CountdownDialogEndOnInactive = endoninactive;
   int ret = DialogBox( CountdownDialogInstance, 
      MAKEINTRESOURCE(IDD_COUNTDOWN), hwnd, CountdownDialogProcedure );
   if ( ret <= 0 )
   {
      char achCaption[256];
      //char achPrompt[256];
      LoadString( CountdownDialogInstance, IDS_CDD, achCaption, sizeof( achCaption ) );
      //LoadString( CountdownDialogInstance, IDS_ERROR_NULL_PARENT_HWND, achPrompt, sizeof( achPrompt ) );
      DWORD dw = GetLastError();
      char ach[128];
      wsprintf( ach, "Create dialog failed[%d]; GetLastError()=%d", ret, (int)dw );
      MessageBox( NULL, ach, achCaption, MB_OK | MB_ICONINFORMATION );
   }
   return ret;
}

// debug: C:\My Projects\Examples\_Win32\CountdownDialog\Debug\CountdownDialogTest.exe
