// Controls.h
//
// CButton, CStatic, CEdit, CComboBox, 
// CListBox, CCheckBox, CRadioButton
//
// Originally, these classes were used in a modeless dialog
// example.
//
// Revision Log
//
// Date       Who SAR     Notes
// ========== === ======= =====================================
//            bm          (c) Bartosz Milewski of www.relisoft.com
// 2001-10-09 mph         Make it work with a modal dialog class
// 2001-10-09 mph         Add lots of new methods
// 2001-10-11 mph         Loads of combobox methods
//
//
#ifndef _CONTROLS_H_INCLUDED
#define _CONTROLS_H_INCLUDED

#include <windows.h>
#include <string>

#include <commctrl.h>

namespace rfc
{

class CSimpleControl
{
public:
   CSimpleControl()
      :  _hWnd( 0 )
   {
   }
   CSimpleControl( HWND hwndParent, int id, BOOL initialState=TRUE )
       : _hWnd( GetDlgItem( hwndParent, id ) )
   {
      if ( initialState == FALSE )
         Disable();
   }
   void Initialize( HWND h, int id )
   {
      _hWnd = GetDlgItem( h, id );
   }
   HWND GetHwnd() { return _hWnd; }
   void Hide()
   {
      ::ShowWindow( _hWnd , SW_HIDE );
   }
   void Show()
   {
      ::ShowWindow( _hWnd , SW_SHOW );
   }
   BOOL IsVisible()
   {
      return ( ::IsWindowVisible( _hWnd ) );
   }
   void SetFocus()
   {
       ::SetFocus( _hWnd );
   }
   void Enable()
   {
       ::EnableWindow( _hWnd , TRUE );
   }
   void Disable()
   {
       ::EnableWindow( _hWnd , FALSE );
   }
	HWND Hwnd() const { return _hWnd; }

protected:
    HWND _hWnd;
};

class CButton : public CSimpleControl
{
public:
   CButton()
      :  CSimpleControl()
   {}
   CButton( HWND hwndParent, int id, BOOL initialState=TRUE )
       : CSimpleControl( hwndParent, id, initialState )
   {}
   void SetText( char const * newName )
   {
      SendMessage( _hWnd, WM_SETTEXT, 0,(LPARAM)newName );
   }
   void SetText( const std::string& s ) { SetText( s.c_str() ); }
   int GetText( const char* lpch, int cchMax ) 
   { 
      return GetWindowText( _hWnd,(char*) lpch, cchMax ); 
   }
   int GetText( std::string& s ) 
   {
      char ach[100];
      int n = GetWindowText( _hWnd,(char*) ach, sizeof( ach )-1 );
      s = ach;
      return n;
   }
   const char* GetText() 
   {
      char ach[256];
      int n = GetWindowText( _hWnd,(char*) ach, sizeof( ach )-1 );
      if ( n > 0 )
         _sTemp = ach;
      else
         _sTemp = "";
      return _sTemp.c_str();
   }
   int GetTextLength() { return GetWindowTextLength( _hWnd ); }
   /*
   int  GetState() { return SendMessage( _hWnd, BM_GETSTATE, 0, 0 ); }
   UINT SetState( int state ) { return SendMessage( _hWnd, BM_SETSTATE,(WPARAM)state, 0 ); }
   void SetStyle( int style, bool redraw ) { SendMessage( _hWnd, BM_SETSTYLE,(WPARAM)LOWORD( style ), MAKELPARAM( (( redraw )?TRUE:FALSE ), 0 ) ); }
   */
private:
    std::string _sTemp;
};

class CCheckBox : public CButton
{
public:
   CCheckBox()
      :  CButton()
   {}
   CCheckBox( HWND hwndParent, int id, BOOL initialState=TRUE )
       : CButton( hwndParent, id, initialState )
   {}
   const char* GetText() 
   {
      char ach[256];
      int n = GetWindowText( _hWnd,(char*) ach, sizeof( ach )-1 );
      if ( n > 0 )
         _sTemp = ach;
      else
         _sTemp = "";
      return _sTemp.c_str();
   }
   void SetText( char const * newName )
   {
      SendMessage( _hWnd, WM_SETTEXT, 0,(LPARAM)newName );
   }
   void SetText( const std::string& s ) { SetText( s.c_str() ); }
   BOOL IsChecked()
   {
      return ( SendMessage( _hWnd, BM_GETCHECK, 0, 0 ) == BST_CHECKED );
   }
   void Check()
   {
      SendMessage( _hWnd, BM_SETCHECK,(WPARAM) BST_CHECKED, 0 );
   }
   void UnCheck()
   {
      SendMessage( _hWnd, BM_SETCHECK,(WPARAM) BST_UNCHECKED, 0 );
   }
private:
    std::string _sTemp;
};

class CRadioButton: public CButton
{
public:
   CRadioButton()
      :  CButton()
   {}
   CRadioButton( HWND hwndParent, int id, BOOL initialState=TRUE )
       : CButton( hwndParent, id, initialState )
   {}
   BOOL IsSelected()
   {
      return ( SendMessage( _hWnd, BM_GETCHECK, 0, 0 ) == BST_CHECKED );
   }
   void Select()
   {
      SendMessage( _hWnd, BM_SETCHECK,(WPARAM) BST_CHECKED, 0 );
   }
   void SetText( char const * newName )
   {
      SendMessage( _hWnd, WM_SETTEXT, 0,(LPARAM)newName );
   }
   void SetText( const std::string& s ) { SetText( s.c_str() ); }
   const char* GetText() 
   {
      char ach[256];
      int n = GetWindowText( _hWnd,(char*) ach, sizeof( ach )-1 );
      if ( n > 0 )
         _sTemp = ach;
      else
         _sTemp = "";
      return _sTemp.c_str();
   }
private:
    std::string _sTemp;
};

class CStatic: public CSimpleControl
{
public:
   CStatic()
      :  CSimpleControl()
   {}
   CStatic( HWND hwndParent, int id, BOOL initialState=TRUE )
        :	CSimpleControl( hwndParent, id, initialState )
   {}

   void SetText( const char* buf ) { SendMessage( _hWnd, WM_SETTEXT, 0,(LPARAM) buf ); }
   void SetText( const std::string& s ) { SetText( s.c_str() ); }
   void GetText( char* buf, int len ) { SendMessage( _hWnd, WM_GETTEXT,(WPARAM) len,(LPARAM) buf ); }
   int GetLength() { return ( SendMessage( _hWnd, WM_GETTEXTLENGTH, 0, 0 ) ); }
   const char* GetText() 
   {
      char ach[256];
      int n = GetWindowText( _hWnd,(char*) ach, sizeof( ach )-1 );
      if ( n > 0 )
         _sTemp = ach;
      else
         _sTemp = "";
      return _sTemp.c_str();
   }

   /*
   HICON SetIcon( hIcon ) { return SendMessage( _hWnd, STM_SETICON,(WPARAM)hIcon, 0 ) ); }
   HICON GetIcon( hIcon ) { return SendMessage( _hWnd, STM_GETICON, 0, 0 ); }
   */
private:
    std::string _sTemp;
};

class CEdit: public CSimpleControl
{
public:
   CEdit()
      :  CSimpleControl()
   {}
   CEdit( HWND hwndParent, int id, BOOL initialState=TRUE )
        :	CSimpleControl( hwndParent, id, initialState )
   {}
   void SetText( const char* buf ) 
   { 
      SetWindowText( _hWnd, buf ); 
   }
   void SetText( const std::string& s ) { SetText( s.c_str() ); }
   int GetLength() { return GetWindowTextLength( _hWnd ); }
   int GetText( char* buf, int len ) 
   {
      return GetWindowText( _hWnd, buf, len ); 
   }
   const char* GetText() 
   {
      char ach[256];
      GetText( ach, sizeof( ach ) );
      int n = GetText( ach, sizeof( ach )-1 );
      if ( n > 0 )
         _sTemp = ach;
      else
         _sTemp = "";
      return _sTemp.c_str();
   }
   void Select() { SendMessage( _hWnd, EM_SETSEL, 0, -1 ); }
   void ClearSelection() { SendMessage( _hWnd, EM_SETSEL, -1, 0 ); }

   // code is the HIWORD(WPARAM)
   //BOOL IsChanged( int code ) { return code == EN_CHANGE; }

   void LimitText( int max ) { SendMessage( _hWnd, EM_LIMITTEXT,(WPARAM)( max ), 0 ); }
   int GetLineCount() { return SendMessage( _hWnd, EM_GETLINECOUNT, 0, 0 ); }

   /*
   GetLine( int line, const char* lpch, int max ) 
   { 
      int n = SendMessage( _hWnd, EM_GETLINE,(WPARAM)line ,(LPARAM)lpch ); 
      if ( n >( max - 1 ) )
   }
   */
   void GetRect( RECT& lprc ) 
   { 
      SendMessage( _hWnd, EM_GETRECT, 0,(LPARAM)&lprc ); 
   }
   void SetRect( RECT* lprc ) { SendMessage( _hWnd, EM_SETRECT, 0,(LPARAM) lprc  ); }
   void SetRectNoPaint( RECT* lprc ) { SendMessage( _hWnd, EM_SETRECTNP, 0,(LPARAM) lprc ); }
   BOOL GetSel( DWORD& b, DWORD& e ) { return SendMessage( _hWnd, EM_GETSEL,(WPARAM)&b,(LPARAM)&e ) != -1; }
   void SetSel( int ichStart, int ichEnd ) { SendMessage( _hWnd, EM_SETSEL,( ichStart ),( ichEnd ) ); }
   void ReplaceSel( const char* lpszReplace, BOOL undoOK=TRUE ) { SendMessage( _hWnd, EM_REPLACESEL,(WPARAM)undoOK,(LPARAM) lpszReplace  ); }

   BOOL IsChanged() { return GetModify(); }
   BOOL GetModify() { return SendMessage( _hWnd, EM_GETMODIFY, 0, 0 ); }
   void SetModify( BOOL fModified ) { SendMessage( _hWnd, EM_SETMODIFY,(WPARAM)fModified, 0 ); }
   void ScrollCaret() { SendMessage( _hWnd, EM_SCROLLCARET, 0, 0 ); }
   int LineFromChar( int ich ) { return SendMessage( _hWnd, EM_LINEFROMCHAR,(WPARAM) ich, 0 ); }
   int LineIndex( int line ) { return SendMessage( _hWnd, EM_LINEINDEX,(WPARAM) line , 0 ); }
   int LineLength( int line ) { return SendMessage( _hWnd, EM_LINELENGTH,(WPARAM) line , 0 ); }
   void Scroll( int dv, int dh ) { SendMessage( _hWnd, EM_LINESCROLL,(WPARAM) dh ,(LPARAM) dv  ); }
   BOOL CanUndo() { SendMessage( _hWnd, EM_CANUNDO, 0, 0 ); }
   BOOL Undo() { SendMessage( _hWnd, EM_UNDO, 0, 0 ); }
   void EmptyUndoBuffer() { SendMessage( _hWnd, EM_EMPTYUNDOBUFFER, 0, 0 ); }
   void SetPasswordChar( char ch ) { SendMessage( _hWnd, EM_SETPASSWORDCHAR,(WPARAM) ch , 0 ); }
   void SetTabStopsDefault() { SendMessage( _hWnd, EM_SETTABSTOPS, 0 , 0 ); }
   void SetTabSpacing( int cTabSpacing ) { SendMessage( _hWnd, EM_SETTABSTOPS,(WPARAM) 1 ,(LPARAM) cTabSpacing  ); }
   void SetTabStops( int cTabs, int* lpTabs ) { SendMessage( _hWnd, EM_SETTABSTOPS,(WPARAM) cTabs ,(LPARAM) lpTabs  ); }
   BOOL FmtLines( BOOL fAddEOL ) { return SendMessage( _hWnd, EM_FMTLINES,(WPARAM) fAddEOL , 0 ); }
   /*
   HANDLE GetHandle() { return SendMessage( _hWnd, EM_GETHANDLE, 0, 0 ); }
   SetHandle( HANDLE hh ) { SendMessage( _hWnd, EM_SETHANDLE,(WPARAM) hh , 0 ); }
   */
#if ( WINVER >= 0x030a )
   int GetFirstVisibleLine() { return SendMessage( _hWnd, EM_GETFIRSTVISIBLELINE, 0, 0 ); }
   BOOL SetReadOnly( BOOL ReadOnly ) { SendMessage( _hWnd, EM_SETREADONLY,(WPARAM) ReadOnly , 0 ); }
   TCHAR GetPasswordChar() { return ( TCHAR ) SendMessage( _hWnd, EM_GETPASSWORDCHAR, 0, 0 ); }

   //void SetWordBreakProc( EDITWORDBREAKPROC* lpfnWordBreak ) { void )SendMessage( _hWnd, EM_SETWORDBREAKPROC, 0,(LPARAM) lpfnWordBreak  ) ); }
   //GetWordBreakProc() { ( EDITWORDBREAKPROC )SendMessage( _hWnd, EM_GETWORDBREAKPROC, 0, 0 ); }
#endif /* WINVER >= 0x030a */
private:
    std::string _sTemp;
};

class CComboBox: public CSimpleControl
{
public:
   CComboBox()
      :  CSimpleControl()
   {}
   CComboBox( HWND hwndParent, int id, BOOL initialState=TRUE )
        :	CSimpleControl( hwndParent, id, initialState )
   {}
   void SetText( const char* buf ) 
   { 
      SetWindowText( _hWnd, buf ); 
   }
   void SetText( const std::string& s ) { SetText( s.c_str() ); }
   int GetLength() { return GetWindowTextLength( _hWnd ); }
   int GetText( char* buf, int len ) 
   {
      return GetWindowText( _hWnd, buf, len ); 
   }
   const char* GetText() 
   {
      char ach[256];
      GetText( ach, sizeof( ach ) );
      int n = GetText( ach, sizeof( ach )-1 );
      if ( n > 0 )
         _sTemp = ach;
      else
         _sTemp = "";
      return _sTemp.c_str();
   }

   void ResetContent() { SendMessage( _hWnd, CB_RESETCONTENT, 0, 0 ); }
   void LimitText( int cchLimit ) { SendMessage( _hWnd, CB_LIMITTEXT,(WPARAM) cchLimit , 0 ); }

   DWORD GetEditSel() { return SendMessage( _hWnd, CB_GETEDITSEL, 0L, 0L ); }
   int SetEditSel( int ichStart, int ichEnd ) { return SendMessage( _hWnd, CB_SETEDITSEL, 0L, MAKELPARAM( ichStart, ichEnd ) ); }
   int GetCount() { return SendMessage( _hWnd, CB_GETCOUNT, 0L, 0L ); }
   int AddString( const char* lpsz ) { return SendMessage( _hWnd, CB_ADDSTRING, 0,(LPARAM)lpsz ); }
   int InsertString( int index, const char* lpsz ) { return SendMessage( _hWnd, CB_INSERTSTRING,(WPARAM)index,(LPARAM)lpsz ); }
   int AddItemData( void* data ) { return SendMessage( _hWnd, CB_ADDSTRING, 0L,(LPARAM)data ); }
   int InsertItemData( int index, void* data ) { return SendMessage( _hWnd, CB_INSERTSTRING,(WPARAM)index,(LPARAM)data ); }
   int DeleteString( int index ) { return SendMessage( _hWnd, CB_DELETESTRING,(WPARAM)index, 0 ); }
   int GetLBTextLen( int index ) { return SendMessage( _hWnd, CB_GETLBTEXTLEN,(WPARAM)index, 0 ); }
   int GetLBText( int index, const char* lpszBuffer ) { return SendMessage( _hWnd, CB_GETLBTEXT,(WPARAM)index,(LPARAM)lpszBuffer ); }
   // LRESULT GetItemData( index ) { return ( ( LRESULT )( DWORD )SendMessage( _hWnd, CB_GETITEMDATA,(WPARAM)(int)( index ), 0L ) ); }
   // int SetItemData( index, data ) { return ( (int)( DWORD )SendMessage( _hWnd, CB_SETITEMDATA,(WPARAM)(int)( index ),(LPARAM)( data ) ) ); }
   int FindString( int indexStart, const char* lpszFind ) { return SendMessage( _hWnd, CB_FINDSTRING,(WPARAM)indexStart,(LPARAM)lpszFind ); }
   // int FindItemData( int indexStart, void* data ) { return SendMessage( _hWnd, CB_FINDSTRING,(WPARAM)indexStart,(LPARAM)data ); }
   int GetCurSel() { return SendMessage( _hWnd, CB_GETCURSEL, 0L, 0L ); }
   int SetCurSel( int index = 0 ) { return SendMessage( _hWnd, CB_SETCURSEL,(WPARAM)index, 0L ); }
   int SelectString( int indexStart, const char* lpszSelect ) { return SendMessage( _hWnd, CB_SELECTSTRING,(WPARAM)indexStart,(LPARAM)lpszSelect ); }
   // int SelectItemData( indexStart, data ) { return ( (int)( DWORD )SendMessage( _hWnd, CB_SELECTSTRING,(WPARAM)(int)( indexStart ),(LPARAM)( data ) ) ); }
   int Dir( UINT attrs, const char* lpszFileSpec ) { return SendMessage( _hWnd, CB_DIR,(WPARAM)attrs,(LPARAM)lpszFileSpec ); }
   BOOL ShowDropdown( BOOL fShow ) { return SendMessage( _hWnd, CB_SHOWDROPDOWN,(WPARAM)fShow, 0L ); }
#if ( WINVER >= 0x030a )
   int FindStringExact( int indexStart, const char* lpszFind ) { return SendMessage( _hWnd, CB_FINDSTRINGEXACT,(WPARAM)indexStart,(LPARAM)lpszFind ); }
   // BOOL GetDroppedState() { return ( ((( bool )))( DWORD )SendMessage( _hWnd, CB_GETDROPPEDSTATE, 0L, 0L ) ); }
   // void GetDroppedControlRect( RECT& rect ) { SendMessage( _hWnd, CB_GETDROPPEDCONTROLRECT, 0,(LPARAM)&rect ); }
   // int GetItemHeight() { return ( (int)( DWORD )SendMessage( _hWnd, CB_GETITEMHEIGHT, 0L, 0L ) ); }
   // int SetItemHeight( index, cyItem ) { return ( (int)( DWORD )SendMessage( _hWnd, CB_SETITEMHEIGHT,(WPARAM)(int)( index ),(LPARAM)(int)cyItem ) ); }
   // UINT GetExtendedUI() { return ( ( UINT )( DWORD )SendMessage( _hWnd, CB_GETEXTENDEDUI, 0L, 0L ) ); }
   // int SetExtendedUI( flags ) { return ( (int)( DWORD )SendMessage( _hWnd, CB_SETEXTENDEDUI,(WPARAM)( UINT )( flags ), 0L ) ); }
#endif  // WINVER >= 0x030a

private:
    std::string _sTemp;
};

class CListBox: public CSimpleControl
{
public:
   CListBox()
      :  CSimpleControl()
   {}
   CListBox( HWND hwndParent, int id, BOOL initialState=TRUE )
        :	CSimpleControl( hwndParent, id, initialState )
   {}
   int AddItemData( void* data )
   {
      return ( DWORD )SendMessage( _hWnd, LB_ADDSTRING, 0L,(LPARAM)data );
   }
   int AddString( const char* lpsz )
   {
      return SendMessage( _hWnd, LB_ADDSTRING, 0L,(LPARAM)lpsz );
   }
   int DeleteString( int index )
   {
      return SendMessage( _hWnd, LB_DELETESTRING,(WPARAM)index, 0L );
   }
   int Dir( UINT attrs, const char* lpszFileSpec )
   {
      return SendMessage( _hWnd, LB_DIR,(WPARAM)attrs,(LPARAM)lpszFileSpec );
   }
   BOOL Enable( BOOL fEnable )
   {
      return EnableWindow( _hWnd, fEnable );
   }
   int GetCount()
   {
      return SendMessage( _hWnd, LB_GETCOUNT, 0L, 0L );
   }
   void* GetItemData( int index )
   {
      return (void*)SendMessage( _hWnd, LB_GETITEMDATA,(WPARAM)index, 0L );
   }
   int GetText( int index, const char* lpszBuffer )
   {
      return SendMessage( _hWnd, LB_GETTEXT,(WPARAM)index,(LPARAM)( lpszBuffer ) );
   }
   int GetTextLen( int index )
   {
      return SendMessage( _hWnd, LB_GETTEXTLEN,(WPARAM)index, 0L );
   }
   int InsertItemData( int index, void* data )
   {
      return SendMessage( _hWnd, LB_INSERTSTRING,(WPARAM)index,(LPARAM)data );
   }
   int InsertString( int index, const char* lpsz )
   {
      return SendMessage( _hWnd, LB_INSERTSTRING,(WPARAM)index,(LPARAM)lpsz );
   }
   BOOL ResetContent()
   {
      return SendMessage( _hWnd, LB_RESETCONTENT, 0L, 0L );
   }
   int SetItemData( int index, void* data )
   {
      return SendMessage( _hWnd, LB_SETITEMDATA,(WPARAM)index,(LPARAM)data );
   }

#if ( WINVER >= 0x030a )
   int FindItemData( int indexStart, void* data )
   {
      return SendMessage( _hWnd, LB_FINDSTRING,(WPARAM)indexStart,(LPARAM)data );
   }
   int FindString( int indexStart, const char* lpszFind )
   {
      return SendMessage( _hWnd, LB_FINDSTRING,(WPARAM)indexStart,(LPARAM)lpszFind );
   }
   int FindStringExact( int indexStart, const char* lpszFind )
   {
      return SendMessage( _hWnd, LB_FINDSTRINGEXACT,(WPARAM)indexStart,(LPARAM)lpszFind );
   }
   int GetCaretIndex()
   {
      return SendMessage( _hWnd, LB_GETCARETINDEX, 0L, 0L );
   }
   int GetCurSel()
   {
      return SendMessage( _hWnd, LB_GETCURSEL, 0L, 0L );
   }
   int GetHorizontalExtent()
   {
      return SendMessage( _hWnd, LB_GETHORIZONTALEXTENT, 0L, 0L );
   }
   int GetItemHeight( int index )
   {
      return SendMessage( _hWnd, LB_GETITEMHEIGHT,(WPARAM)index, 0L );
   }
   int GetItemRect( int index, RECT& lprc )
   {
      return SendMessage( _hWnd, LB_GETITEMRECT,(WPARAM)index,(LPARAM)&lprc );
   }
   int GetSel( int index )
   {
      return SendMessage( _hWnd, LB_GETSEL,(WPARAM)index, 0L );
   }
   int GetSelCount()
   {
      return SendMessage( _hWnd, LB_GETSELCOUNT, 0L, 0L );
   }
   int GetSelItems( int cItems, int* lpItems )
   {
      return SendMessage( _hWnd, LB_GETSELITEMS,(WPARAM)cItems,(LPARAM)lpItems );
   }
   int GetTopIndex()
   {
      return SendMessage( _hWnd, LB_GETTOPINDEX, 0L, 0L );
   }
   int SelItemRange( BOOL fSelect, int first, int last )
   {
      return SendMessage( _hWnd, LB_SELITEMRANGE,(WPARAM)fSelect, MAKELPARAM( ( first ),( last ) ) );
   }
   int SelectItemData( int indexStart, void* data )
   {
      return SendMessage( _hWnd, LB_SELECTSTRING,(WPARAM)indexStart,(LPARAM)data );
   }
   int SelectString( int indexStart, const char* lpszFind )
   {
      return SendMessage( _hWnd, LB_SELECTSTRING,(WPARAM)indexStart,(LPARAM)lpszFind );
   }
   int SetCaretIndex( int index )
   {
      return SendMessage( _hWnd, LB_SETCARETINDEX,(WPARAM)index, 0L );
   }
   void SetColumnWidth( int cxColumn )
   {
      SendMessage( _hWnd, LB_SETCOLUMNWIDTH,(WPARAM)( cxColumn ), 0L );
   }
   int SetCurSel( int index )
   {
      return SendMessage( _hWnd, LB_SETCURSEL,(WPARAM)index, 0L );
   }
   void SetHorizontalExtent( int cxExtent )
   {
      SendMessage( _hWnd, LB_SETHORIZONTALEXTENT,(WPARAM)cxExtent, 0L );
   }
   int SetItemHeight( int index, int cy )
   {
      return SendMessage( _hWnd, LB_SETITEMHEIGHT,(WPARAM)index, MAKELPARAM( cy, 0 ) );
   }
   int SetSel( BOOL fSelect, int index )
   {
      return SendMessage( _hWnd, LB_SETSEL,(WPARAM)fSelect,(LPARAM)index );
   }
   BOOL SetTabStops( int cTabs, int* lpTabs )
   {
      return SendMessage( _hWnd, LB_SETTABSTOPS,(WPARAM)cTabs,(LPARAM)lpTabs );
   }
   int SetTopIndex( int indexTop )
   {
      return SendMessage( _hWnd, LB_SETTOPINDEX,(WPARAM)indexTop, 0L );
   }
#endif  // WINVER >= 0x030a

};

class CProgressBar: public CSimpleControl
{
public:
   CProgressBar()
      :  CSimpleControl()
   {}
   CProgressBar( HWND hwndParent, int id, BOOL initialState=TRUE )
       : CSimpleControl( hwndParent, id, initialState )
   {}

   void SetRange( int nMinRange=0, int nMaxRange=100 )
   {
      SendMessage( _hWnd, PBM_SETRANGE, 0, MAKELPARAM( nMinRange, nMaxRange ) );
   }
   int SetPos( int nNewPos )
   {
      return SendMessage( _hWnd, PBM_SETPOS,(WPARAM) nNewPos, 0 );
   }
   int DeltaPos( int nIncrement )
   {
      return SendMessage( _hWnd, PBM_DELTAPOS,(WPARAM) nIncrement, 0 );
   }
   int SetStep( int nStepInc )
   {
      return SendMessage( _hWnd, PBM_SETSTEP,(WPARAM) nStepInc, 0 );
   }
   int StepIt()
   {
      return SendMessage( _hWnd, PBM_STEPIT, 0, 0 );
   }
};

} // end namespace rfc

#endif // _CONTROLS_H_INCLUDED
